==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-volume/volume_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="62"/>
        <source>Increase sound volume</source>
        <translation>Увеличить громкость звука</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="68"/>
        <source>Decrease sound volume</source>
        <translation>Уменьшить громкость звука</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="74"/>
        <source>Mute/unmute sound volume</source>
        <translation>Выкл/вкл звук</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="135"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Контроль громкости: следующие сочетания клавиш не могут быть зарегистрированы: %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="223"/>
        <location filename="../../../lxqtvolume.cpp" line="233"/>
        <source>Volume: %1</source>
        <translation>Громкость: %1</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Настройки контроля громкости</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Контролируемое устройство</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="28"/>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Отключать звук при щелчке средней кнопкой мыши</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Показать по щелчку мыши</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Разрешить громкость выше 100% (0дБ)</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="92"/>
        <source>Volume adjust step</source>
        <translation>Шаг регулировки громкости</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="111"/>
        <source>External Mixer</source>
        <translation>Внешний микшер</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../../../volumepopup.cpp" line="53"/>
        <source>Launch mixer</source>
        <translation>Запустить микшер</translation>
    </message>
    <message>
        <location filename="../../../volumepopup.cpp" line="54"/>
        <source>Mi&amp;xer</source>
        <translation>Ми&amp;кшер</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-panel/plugin-volume/volume_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="63"/>
        <source>Increase sound volume</source>
        <translation>Увеличить громкость звука</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="69"/>
        <source>Decrease sound volume</source>
        <translation>Уменьшить громкость звука</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="75"/>
        <source>Mute/unmute sound volume</source>
        <translation>Выкл/вкл звук</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="136"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Контроль громкости: следующие сочетания клавиш не могут быть зарегистрированы: %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="287"/>
        <source>Volume: muted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="289"/>
        <source>Volume: %1%</source>
        <translation type="unfinished">Громкость: %1%</translation>
    </message>
    <message>
        <source>Volume: %1</source>
        <translation type="vanished">Громкость: %1</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Настройки контроля громкости</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Контролируемое устройство</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="28"/>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Отключать звук при щелчке средней кнопкой мыши</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Показать по щелчку мыши</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Разрешить громкость выше 100% (0дБ)</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>Шаг регулировки громкости</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>Внешний микшер</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../../../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>Запустить микшер</translation>
    </message>
    <message>
        <location filename="../../../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>Ми&amp;кшер</translation>
    </message>
</context>
</TS>
